@@ -62,7 +62,6 @@ import java.net.URL;
 import java.net.URLConnection;
 import java.net.URLDecoder;
 import java.util.HashMap;
-import java.util.zip.CRC32;
 import java.util.zip.CheckedInputStream;
 import org.apache.commons.io.FileUtils;
 import org.apache.commons.io.IOUtils;
@@ -72,6 +71,8 @@ import org.apache.commons.lang.StringUtils;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 import com.google.common.base.Throwables;
+import jonelo.jacksum.JacksumAPI;
+import jonelo.jacksum.algorithm.AbstractChecksum;
 
 
 /**
@@ -96,13 +97,15 @@ public class DocumentConverterManager {
 
     final private static int HTTP_CACHESERVER_READ_TIMEOUT_MS=60000;
 
+    final private static String UNKNOWN_FILENAME = "n/a";
+
     /**
      * Initializes a new {@link DocumentConverterManager}.
      */
-    public DocumentConverterManager(final File tmpRootDir) {
+    public DocumentConverterManager(@NonNull final File tmpRootDir) {
         super();
 
-        m_tmpRootDir = (null != tmpRootDir) ? tmpRootDir : FileUtils.getTempDirectory();
+        m_tmpRootDir = tmpRootDir;
     }
 
     /**
@@ -119,7 +122,7 @@ public class DocumentConverterManager {
     public File createTempFile(@NonNull String tmpFilePrefix) {
         File ret = null;
 
-        if ((m_tmpRootDir.isDirectory() && m_tmpRootDir.canWrite()) || mkdirs(m_tmpRootDir)) {
+        if (validateOrMkdir(m_tmpRootDir)) {
             // create a temp. file with the name 'prefix*.tmp' within the configured documentconverter cache directory
 
             try {
@@ -167,24 +170,22 @@ public class DocumentConverterManager {
      * @param dirFile
      * @return
      */
-    public static boolean mkdirs(File directory) {
-        boolean ret = false;
-
-        if (null != directory) {
-            if (!directory.exists()) {
+    public static boolean validateOrMkdir(File directoryFile) {
+        if (null != directoryFile) {
+            if (!directoryFile.exists()) {
                 try {
-                    FileUtils.forceMkdir(directory);
+                    FileUtils.forceMkdir(directoryFile);
                 } catch (final IOException e) {
                     logExcp(e);
                 }
 
-                FileUtils.waitFor(directory, 3);
+                FileUtils.waitFor(directoryFile, 3);
             }
 
-            ret = directory.canWrite();
+            return (directoryFile.isDirectory() && directoryFile.canWrite());
         }
 
-        return ret;
+        return false;
     }
 
     /**
@@ -284,22 +285,6 @@ public class DocumentConverterManager {
         return inputFile;
     }
 
-    /**
-     * @param file
-     * @param deleteFile
-     * @return
-     */
-    public boolean deleteFileIfFlagged(@NonNull File file, @NonNull MutableWrapper<Boolean> deleteFile) {
-        boolean ret = deleteFile.get().booleanValue();
-
-        if (ret) {
-            FileUtils.deleteQuietly(file);
-            deleteFile.set(Boolean.FALSE);
-        }
-
-        return ret;
-    }
-
     // static methods
 
     /**
@@ -314,9 +299,9 @@ public class DocumentConverterManager {
             hashBuilder = new StringBuilder(256);
 
             try {
-                hashBuilder.append(Long.toString(file.length())).append('_');
+                final AbstractChecksum checksum = JacksumAPI.getChecksumInstance("sha-256");
 
-                CRC32 checksum = new CRC32();
+                checksum.setEncoding("hex");
 
                 try (final InputStream inputStm = new CheckedInputStream(new FileInputStream(file), checksum);
                      final NullOutputStream outputStm = new NullOutputStream()) {
@@ -324,7 +309,8 @@ public class DocumentConverterManager {
                     IOUtils.copy(inputStm, outputStm);
                 }
 
-                hashBuilder.append(Long.toString(checksum.getValue())).append('-');
+                hashBuilder.append(checksum.getFormattedValue());
+                hashBuilder.append('-');
             } catch (final Exception e) {
                 logExcp(e);
             }
@@ -373,6 +359,22 @@ public class DocumentConverterManager {
         }
     }
 
+    /**
+     * @param filename
+     */
+    public static String getFilenameForLog(String filename) {
+        try {
+            return (null != filename) ?
+                URLDecoder.decode(filename.replaceAll("%(?![0-9a-fA-F]{2})", "%25"), "UTF-8") :
+                    UNKNOWN_FILENAME;
+        } catch (@SuppressWarnings("unused") final UnsupportedEncodingException e) {
+            // ok
+        }
+
+        return filename;
+    }
+
+
     // - Logging ---------------------------------------------------------------
 
     /**
@@ -513,8 +515,8 @@ public class DocumentConverterManager {
     static public void logExcp(Exception e) {
         if (isLogError()) {
             final Throwable rootCause = Throwables.getRootCause(e);
-            final String rootCauseMessage = (null != rootCause) ? rootCause.getMessage() : "";
-            final String lowerCaseRootCauseMessage = rootCauseMessage.toLowerCase();
+            final String rootCauseMessage = (null != rootCause) ? rootCause.getMessage() : "n/a";
+            final String lowerCaseRootCauseMessage = (null != rootCauseMessage) ? rootCauseMessage.toLowerCase() : "n/a";
             String message = e.getMessage();
 
             if ((rootCause instanceof SocketException) ||
@@ -559,6 +561,8 @@ public class DocumentConverterManager {
             fileName = (String) jobProperties.get(Properties.PROP_INFO_FILENAME);
         }
 
+        final boolean addClosingBrace = (extraData.length > 0) || (null != fileName);
+
         if (extraData.length > 0) {
             logMessageBuilder.append(" (");
 
@@ -579,25 +583,11 @@ public class DocumentConverterManager {
             }
         }
 
+        // add decoded file name
         if (null != fileName) {
-            try {
-                // #63629: encode all percentage characters being
-                // non-percentage encodings before decoding file name
-                fileName = URLDecoder.decode(fileName.replaceAll("%(?![0-9a-fA-F]{2})", "%25"), "UTF-8");
-            } catch (final UnsupportedEncodingException e) {
-                logExcp(e);
-            }
-
-            if (extraData.length > 0) {
-                logMessageBuilder.append(", filename=");
-            } else {
-                logMessageBuilder.append(" (filename=");
-            }
-
-            logMessageBuilder.append(fileName).append(')');
-        } else if (extraData.length > 0) {
-            logMessageBuilder.append(')');
-
+            logMessageBuilder.
+                append((extraData.length > 0) ? ", " : " (").append("filename=").
+                append(DocumentConverterManager.getFilenameForLog(fileName));
         }
 
         if ((null != jobProperties) && !jobProperties.isEmpty()) {
@@ -616,16 +606,16 @@ public class DocumentConverterManager {
                         (null != obj) ? obj.toString() : "null");
                 }
             }
-
-            if (null != infoStrBuilder) {
-                infoStrBuilder.append(')');
-            }
         }
 
         if (null != infoStrBuilder) {
             logMessageBuilder.append(infoStrBuilder);
         }
 
+        if (addClosingBrace) {
+            logMessageBuilder.append(')');
+        }
+
         return logMessageBuilder.toString();
     }
 
