@@ -182,8 +182,8 @@ public class HttpHelper {
             httpConnection.setUseCaches(false);
             httpConnection.setDoOutput(true);
             httpConnection.setAllowUserInteraction(false);
-            httpConnection.setConnectTimeout(DocumentConverterManager.getHTTPConnectTimeoutMilliseconds(serverType));
-            httpConnection.setReadTimeout(DocumentConverterManager.getHTTPReadTimeoutMilliseconds(serverType));
+            httpConnection.setConnectTimeout(DocumentConverterManager.getHTTPConnectTimeoutMillis(serverType));
+            httpConnection.setReadTimeout(DocumentConverterManager.getHTTPReadTimeoutMillis(serverType));
 
             // set Cookie if requested
             final String callCookie = transferObj.getCookie();
@@ -244,8 +244,8 @@ public class HttpHelper {
             httpConnection.setDoOutput(true);
             httpConnection.setUseCaches(false);
             httpConnection.setAllowUserInteraction(false);
-            httpConnection.setConnectTimeout(DocumentConverterManager.getHTTPConnectTimeoutMilliseconds(serverType));
-            httpConnection.setReadTimeout(DocumentConverterManager.getHTTPReadTimeoutMilliseconds(serverType));
+            httpConnection.setConnectTimeout(DocumentConverterManager.getHTTPConnectTimeoutMillis(serverType));
+            httpConnection.setReadTimeout(DocumentConverterManager.getHTTPReadTimeoutMillis(serverType));
 
             // set Cookie if requested
             final String callCookie = transferObj.getCookie();
