@@ -70,7 +70,7 @@ import com.google.common.base.Throwables;
  * @author <a href="mailto:kai.ahrens@open-xchange.com">Kai Ahrens</a>
  * @since v7.10.1
  */
-public final class PDFExtractor {
+public class PDFExtractor {
 
     final public static int PDFTOOL_ERRORCODE_NONE = 0x00000000;
 
@@ -78,6 +78,8 @@ public final class PDFExtractor {
 
     final public static int PDFTOOL_ERRORCODE_PASSWORD = 0x00000010;
 
+    final private static String PDF_EXTRACTOR_LOG_PREFIX = "DC PDFExtractor";
+
     /**
      * Unused
      */
@@ -93,16 +95,26 @@ public final class PDFExtractor {
         super();
 
         if (!pdfExecutable.canExecute()) {
-            throw new IOException("DC PDF extraction tool binary cannot be found or executed: " +
-                pdfExecutable.getAbsolutePath());
+            throw new IOException(implGetLogBuilder("external tool cannot be found or executed: ").
+                append(pdfExecutable.getAbsolutePath()).toString());
         } else if (LOG.isTraceEnabled()) {
-            LOG.trace("DC PDF extraction tool found: " + pdfExecutable.getAbsolutePath());
+            LOG.trace(implGetLogBuilder("external tool found: ").
+                append(pdfExecutable.getAbsolutePath()).toString());
         }
 
         m_manager = manager;
         m_pdfExecutable = pdfExecutable;
     }
 
+    /**
+     * getLogPrefix
+     *
+     * @return
+     */
+    public String getLogPrefix() {
+        return PDF_EXTRACTOR_LOG_PREFIX;
+    }
+
     /**
      * @param pdfInputFile
      * @return
@@ -126,8 +138,8 @@ public final class PDFExtractor {
                 }
             }
         } catch (Throwable e) {
-            LOG.error("DC PDF extraction tool caught exception when getting page count of PDF file: {}",
-                Throwables.getRootCause(e).getMessage());
+            LOG.error(implGetLogBuilder("caught exception when getting page count of PDF file: ").
+                append(Throwables.getRootCause(e).getMessage()).toString());
 
             ret = -1;
         } finally {
@@ -189,8 +201,8 @@ public final class PDFExtractor {
                 implPostProcess(pdfWorkDir, outputFile);
             }
         } catch (Throwable e) {
-            LOG.error("DC PDF extraction tool caught exception when extracting PDF page as graphic: {}",
-                Throwables.getRootCause(e).getMessage());
+            LOG.error(implGetLogBuilder("caught exception when extracting PDF page as graphic: ").
+                append(Throwables.getRootCause(e).getMessage()).toString());
 
             ret = PDFTOOL_ERRORCODE_GENERAL;
         } finally {
@@ -200,6 +212,21 @@ public final class PDFExtractor {
         return ret;
     }
 
+    // - Implementation --------------------------------------------------------
+
+    /**
+     * implGetLogBuilder
+     *
+     * @param logText
+     * @return
+     */
+    private StringBuilder implGetLogBuilder(@Nullable final String logText) {
+        return new StringBuilder(256).
+            append(getLogPrefix()).
+            append(' ').append((null != logText) ? logText : "");
+
+    }
+
     /**
      * @param outputDir The directory, cotaining all extracted page files
      * @param outputFile The file to contain the single extracred page
